@@ -184,6 +184,11 @@ class Channel:
     def moveUser(target_id, user_ids):
         ...
 
+    @staticmethod
+    @req('POST')
+    def update(channel_id, name, topic, slow_mode):
+        ...
+
 
 class ChannelRole:
 
@@ -222,6 +227,19 @@ class ChannelRole:
         ...
 
 
+class ChannelUser:
+
+    @staticmethod
+    @req('GET')
+    def getJoinedChannel(
+        page,
+        page_size,
+        guild_id,
+        user_id
+    ):
+        ...
+
+
 class Message:
 
     @staticmethod
